#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var ms = require("minimist");
var main_1 = require("./main");
var utils_1 = require("./utils");
function parseArguments(args) {
    var minimistOptions = {
        alias: {
            'p': 'project',
            'o': 'outDir',
            'k': 'noClean',
            'g': 'noPkgValidation',
            'd': 'noDepsValidation',
        },
        defaults: {
            outDir: './dist',
            project: undefined,
            noClean: false,
            noPkgValidation: false,
            noDepsValidation: false,
        },
        boolean: ['k', 'noClean', 'g', 'noPkgValidation', 'd', 'noDepsValidation'],
        string: ['o', 'outDir', 'p', 'project'],
    };
    return ms(args, minimistOptions);
}
exports.parseArguments = parseArguments;
if (require && require.main === module) {
    var args = parseArguments(process.argv.slice(2));
    var project = args.project || process.cwd();
    if (!utils_1.isString(project)) {
        throw new Error('Project argument is invalid');
    }
    var projectPath = project.replace(/['"]/g, '');
    var projectConfigPath = '';
    if (!path.isAbsolute(project)) {
        projectPath = path.resolve(process.cwd(), projectPath);
    }
    if (utils_1.isFile(projectPath)) {
        projectConfigPath = path.resolve(projectPath);
        projectPath = path.dirname(project);
    }
    else if (utils_1.isDirectory(projectPath)) {
        projectConfigPath = path.resolve(projectPath, 'tsconfig.json');
    }
    else {
        throw new Error('A valid path is required to project directory or tsconfig!');
    }
    main_1.main(projectPath, projectConfigPath, {
        outDir: args.outDir,
        noClean: args.noClean,
        noPkgValidation: args.noPkgValidation,
        noDepsValidation: args.noDepsValidation,
    })
        .then(function () {
        console.log('Bundle completed successfully!');
        process.exit(0);
    })
        .catch(function (err) {
        var message = (err.stack || err).toString();
        console.error('Bundle halted!\n' + message);
        process.exit(1);
    });
}
